Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/nathanw_sa]: src/sys/arch LWPify



details:   https://anonhg.NetBSD.org/src/rev/717dd0a23e6c
branches:  nathanw_sa
changeset: 506282:717dd0a23e6c
user:      gmcgarry <gmcgarry%NetBSD.org@localhost>
date:      Sat Oct 05 05:44:39 2002 +0000

description:
LWPify

diffstat:

 sys/arch/algor/algor/machdep.c     |  10 +++++-----
 sys/arch/hpcmips/hpcmips/machdep.c |  12 ++++++------
 2 files changed, 11 insertions(+), 11 deletions(-)

diffs (63 lines):

diff -r 090238f2d59b -r 717dd0a23e6c sys/arch/algor/algor/machdep.c
--- a/sys/arch/algor/algor/machdep.c    Sat Oct 05 05:08:42 2002 +0000
+++ b/sys/arch/algor/algor/machdep.c    Sat Oct 05 05:44:39 2002 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: machdep.c,v 1.13.4.5 2002/08/27 23:44:18 nathanw Exp $ */
+/*     $NetBSD: machdep.c,v 1.13.4.6 2002/10/05 05:47:58 gmcgarry Exp $        */
 
 /*-
  * Copyright (c) 2001 The NetBSD Foundation, Inc.
@@ -538,13 +538,13 @@
        pmap_bootstrap();
 
        /*
         * Init mapping for u page(s) for proc0.
         */
        led_display('u', 's', 'p', 'c');
        v = (caddr_t) uvm_pageboot_alloc(USPACE);
-       proc0.p_addr = proc0paddr = (struct user *) v;
-       proc0.p_md.md_regs = (struct frame *)(v + USPACE) - 1;
-       curpcb = &proc0.p_addr->u_pcb;
+       lwp0.l_addr = proc0paddr = (struct user *) v;
+       lwp0.l_md.md_regs = (struct frame *)(v + USPACE) - 1;
+       curpcb = &lwp0.l_addr->u_pcb;
        curpcb->pcb_context[11] = MIPS_INT_MASK | MIPS_SR_INT_IE; /* SR */
 
        /*
@@ -538,13 +538,13 @@
 
        /*
-        * Init mapping for u page(s) for proc0.
+        * Init mapping for u page(s) for lwp0.
         */
        led_display('u', 's', 'p', 'c');
diff -r 090238f2d59b -r 717dd0a23e6c sys/arch/hpcmips/hpcmips/machdep.c
--- a/sys/arch/hpcmips/hpcmips/machdep.c        Sat Oct 05 05:08:42 2002 +0000
+++ b/sys/arch/hpcmips/hpcmips/machdep.c        Sat Oct 05 05:44:39 2002 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: machdep.c,v 1.64.2.8 2002/08/27 23:44:32 nathanw Exp $ */
+/*     $NetBSD: machdep.c,v 1.64.2.9 2002/10/05 05:44:39 gmcgarry Exp $        */
 
 /*-
  * Copyright (c) 1999 Shin Takemura, All rights reserved.
@@ -73,7 +73,7 @@
  */
 
 #include <sys/cdefs.h>                 /* RCS ID & Copyright macro defns */
-__KERNEL_RCSID(0, "$NetBSD: machdep.c,v 1.64.2.8 2002/08/27 23:44:32 nathanw Exp $");
+__KERNEL_RCSID(0, "$NetBSD: machdep.c,v 1.64.2.9 2002/10/05 05:44:39 gmcgarry Exp $");
 
 #include "opt_vr41xx.h"
 #include "opt_tx39xx.h"
@@ -412,13 +412,13 @@
                ddb_init(symbolsz, &end, esym);
 #endif /* DDB */
        /*
         * Alloc u pages for proc0 stealing KSEG0 memory.
         */
-       proc0.p_addr = proc0paddr = (struct user *)kernend;
-       proc0.p_md.md_regs =
+       lwp0.l_addr = proc0paddr = (struct user *)kernend;
+       lwp0.l_md.md_regs =
            (struct frame *)((caddr_t)kernend + UPAGES * PAGE_SIZE) - 1;
        memset(kernend, 0, UPAGES * PAGE_SIZE);
-       curpcb = &proc0.p_addr->u_pcb;
+       curpcb = &lwp0.l_addr->u_pcb;
        curpcb->pcb_context[11] = MIPS_INT_MASK | MIPS_SR_INT_IE; /* SR */
 
        kernend += UPAGES * PAGE_SIZE;
@@ -412,13 +412,13 @@
 #endif /* DDB */
        /*
-        * Alloc u pages for proc0 stealing KSEG0 memory.
+        * Alloc u pages for lwp0 stealing KSEG0 memory.
         */



Home | Main Index | Thread Index | Old Index